PDF2EBook
=========

Convert pdfs to an epub


Dependencies
------------

Poppler - `sudo apt install libpoppler-cpp-dev`
PDFToHTML - `sudo apt install pdftohtml`


Usage
=====

`python convert.py --in something.pdf --out other.epub`
